@@ -209,8 +209,7 @@
 ##'   undertake further analysis.
 ##'
 ##' An openair output can be manipulated using a number of generic operations,
-##'   including \code{print}, \code{plot} and \code{summary}. See
-##'   \code{\link{openair.generics}} for further details.
+##'   including \code{print}, \code{plot} and \code{summary}. 
 ##' @author David Carslaw
 ##' @seealso \code{\link{linearRelation}}, \code{\link{timePlot}} and
 ##'   \code{\link{timeAverage}} for details on selecting averaging times and
@@ -341,7 +340,8 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
     Args$map.alpha <- if ("map.alpha" %in% names(Args)) Args$map.alpha else 0.2
     Args$map.fill <- if ("map.fill" %in% names(Args)) Args$map.fill else TRUE
     Args$map.res <- if ("map.res" %in% names(Args)) Args$map.res else "default"
-
+    Args$traj <- if ("traj" %in% names(Args)) Args$traj else FALSE
+    
     ## transform hexbin by default
     Args$trans <- if ("trans" %in% names(Args)) Args$trans else function(x) log(x)
     Args$inv <- if ("inv" %in% names(Args)) Args$inv else function(x) exp(x)
@@ -402,14 +402,8 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
     if (!is.na(group)) if (group %in% type)
         stop ("Can't have 'group' also in 'type'.")
 
-    ## decide if a trajectory plot is being drawn AND if a line is required rather
-    ## than points
-    traj <- FALSE
-    if (all(c("date", "lat", "lon", "height", "pressure") %in% names(mydata)) &
-        plot.type == "l") traj <- TRUE
-
     ## will need date so that trajectory groups can be coloured
-    if (traj)  vars <- c(vars, "date")
+    if (Args$traj)  vars <- c(vars, "date")
 
     ## data checks
 
@@ -455,38 +449,48 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
         if (!"pch" %in% names(Args)) Args$pch <- 16
 
         nlev <- 200
-
+        
         ## handling of colour scale limits
         if (missing(limits)) {
-            breaks <- pretty(mydata[[z]], n = nlev)
+                      
+            breaks <- seq(min(mydata[[z]], na.rm = TRUE), max(mydata[[z]], na.rm = TRUE),
+                          length.out = nlev)
             labs <- pretty(breaks, 7)
             labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
+            at <- labs
 
         } else {
-
-            breaks <- pretty(limits, n = nlev)
+            ## handle user limits and clipping            
+            breaks <- seq(min(limits), max(limits), length.out = nlev)
             labs <- pretty(breaks, 7)
             labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
+            at <- labs
 
-            if (max(limits) < max(mydata[[z]], na.rm = TRUE)) {
-                ## if clipping highest, then annotate differently
+            ## case where user max is < data max
+            if (max(limits) < max(mydata[[z]], na.rm = TRUE)) {             
                 id <- which(mydata[[z]] > max(limits))
                 mydata[[z]][id] <- max(limits)
-                thecol <- openColours(cols, 100)[cut(mydata[, z], 100, label = FALSE)]
-                mydata$col <- thecol
-                labs <- pretty(breaks, 7)
-                labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
                 labs[length(labs)] <- paste(">", labs[length(labs)])
             }
+
+            ## case where user min is > data min
+            if (min(limits) > min(mydata[[z]], na.rm = TRUE)) {              
+                id <- which(mydata[[z]] < min(limits))
+                mydata[[z]][id] <- min(limits)
+                labs[1] <- paste("<", labs[1])
+            }
+            
+            thecol <- openColours(cols, 100)[cut(mydata[, z], 100, label = FALSE)]
+            mydata$col <- thecol
+                              
         }
 
         if (thekey) {
             nlev2 <- length(breaks)
             col <- openColours(cols, (nlev2 - 1))
-            breaks <- c(breaks[1:(length(breaks) - 1)], max(mydata[[z]], na.rm = TRUE))
-
+        
             col.scale <- breaks
-            legend <- list(col = col, at = col.scale, labels = list(labels = labs),
+            legend <- list(col = col, at = col.scale, labels = list(labels = labs, at = at),
                            space = key.position,
                            auto.text = auto.text, footer = Args$key.footer,
                            header = Args$key.header,
@@ -626,7 +630,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
                             ## specific treatemt of trajectory lines
                             ## in order to avoid a line back to the origin, need to process
                             ## in batches
-                            if (traj) {
+                            if (Args$traj) {
 
                                 if (!is.na(z)) {
                                     ## colour by z
@@ -642,11 +646,15 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
 
                             }
 
-                            if (!is.na(z) & !traj)
+                            ## add base map
+                            if (map && group.number == groupMax)
+                                add.map(Args, ...)
+
+                            if (!is.na(z) & !Args$traj)
                                 panel.xyplot(x, y, col.symbol = thecol[subscripts],
                                                                 as.table = TRUE, ...)
 
-                            if (is.na(z) & !traj)
+                            if (is.na(z) & !Args$traj)
                                 panel.xyplot(x, y, type = plot.type,
                                              col.symbol = myColors[group.number],
                                              col.line = myColors[group.number],
@@ -667,9 +675,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
                                 panel.smooth.spline(x, y, col = "grey20", #myColors[group.number],
                                                     lwd = lwd, ...)
 
-                            ## add base map
-                            if (map && group.number == groupMax)
-                                add.map(Args, ...)
+                            
 
                             if (mod.line && group.number == 1)
                                 panel.modline(log.x, log.y)
@@ -784,10 +790,12 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
             wsp <- rep(x, res)
             wdp <- rep(y, rep(res, res))
 
+            if (Args$traj) d <- 0.05 else d <- 0.02
+
             ## data with gaps caused by min.bin
             all.data <- na.omit(data.frame(xgrid = mydata$xgrid, ygrid = mydata$ygrid, z))
             ind <- with(all.data, exclude.too.far(wsp, wdp, mydata$xgrid,
-                                                  mydata$ygrid, dist = 0.05))
+                                                  mydata$ygrid, dist = d))
 
             new.data[ind, z] <- NA
 
@@ -809,19 +817,27 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
             labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
 
         } else {
-
+            
+           ## handle user limits and clipping
             breaks <- pretty(limits, n = nlev)
             labs <- pretty(breaks, 7)
             labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
 
-            if (max(limits) < max(mydata[[z]], na.rm = TRUE)) {
-                ## if clipping highest, then annotate differently
+            ## case where user max is < data max
+            if (max(limits) < max(mydata[[z]], na.rm = TRUE)) {             
                 id <- which(mydata[[z]] > max(limits))
                 mydata[[z]][id] <- max(limits)
-                labs <- pretty(breaks, 7)
-                labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
                 labs[length(labs)] <- paste(">", labs[length(labs)])
             }
+
+            ## case where user min is > data min
+            if (min(limits) > min(mydata[[z]], na.rm = TRUE)) {              
+                id <- which(mydata[[z]] < min(limits))
+                mydata[[z]][id] <- min(limits)
+                labs[1] <- paste("<", labs[1])
+            }
+            
+           
         }
 
 
@@ -920,6 +936,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
 
     if (method == "density") {
         prepare.grid <- function(subdata) {
+          n <- nrow(subdata) ## for intensity estimate
             x <- subdata[, x]
             y <- subdata[, y]
             xy <- xy.coords(x, y, "xlab", "ylab")
@@ -938,16 +955,16 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
 
             grid <- expand.grid(x = xm, y = ym)
 
-            results <- data.frame(x = grid$x, y = grid$y, z = as.vector(dens))
+            results <- data.frame(x = grid$x, y = grid$y, z = as.vector(dens) * n)
             results
         }
 
         ## ###########################################################################
 
         results.grid <-  ddply(mydata, type, prepare.grid)
-
+        
         ## auto-scaling
-        nlev <- 200  ## preferred number of intervals
+        nlev <- nrow(mydata)  ## preferred number of intervals
         breaks <- pretty(results.grid$z, n = nlev)
 
         nlev2 <- length(breaks)
@@ -955,6 +972,14 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
         col <- openColours(method.col, (nlev2 - 1)) #was "default"??
         col <- c("transparent", col) ## add white at bottom
         col.scale <- breaks
+        
+        legend <- list(col = col, at = col.scale, 
+                       space = key.position,
+                       auto.text = auto.text, footer = "intensity",
+                       header = Args$key.header,
+                       height = 1, width = 1.5, fit = "all")
+        legend <- makeOpenKeyLegend(TRUE, legend, "other")
+        
 
         ## basic function for lattice call + defaults
         temp <- paste(type, collapse = "+")
@@ -970,6 +995,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
                                strip.left = strip.left,
                                par.strip.text = list(cex = 0.8),
                                col.regions = col,
+                               legend = legend,
                                region = TRUE,
                                at = col.scale,
                                colorkey = FALSE,...,
