@@ -145,7 +145,6 @@ summaryPlot <- function(mydata,
     if (length(cols) == 1 && cols == "greyscale") {
         #strip
         current.strip <- trellis.par.get("strip.background")
-        suppressWarnings(trellis.par.set(list(strip.background = list(col = "white"))))
         #other local colours
         col.trend <- "lightgrey"
         col.data <- "lightgrey"
@@ -173,7 +172,7 @@ summaryPlot <- function(mydata,
     extra.args <- extra.args[!names(extra.args) %in% c("xlab", "ylab", "main")]
 
     ## set panel strip to white
-    trellis.par.set(list(strip.background = list(col = "white")))
+    suppressWarnings(trellis.par.set(list(strip.background = list(col = "white"))))
 
 #the above might be a better retro fix for more complex functions?
 
@@ -189,7 +188,7 @@ summaryPlot <- function(mydata,
     }
 
     ## for plot
-    dateBreaks <- openair:::dateBreaks(mydata$date, date.breaks)$major
+    dateBreaks <- dateBreaks(mydata$date, date.breaks)$major
 
     ## print data types - helps with debugging
     print(unlist(sapply(mydata, class)))
@@ -248,11 +247,11 @@ summaryPlot <- function(mydata,
     ## round the dates depending on period
     min.year <- as.numeric(min(format(mydata$date, "%Y")))
     max.year <- as.numeric(max(format(mydata$date, "%Y")))
-    start.date <- as.POSIXct(openair:::dateTrunc(min(mydata$date), period))
-    end.date <- as.POSIXct(openair:::dateCeil(max(mydata$date), period) - 3600)
+    start.date <- as.POSIXct(dateTrunc(min(mydata$date), period))
+    end.date <- as.POSIXct(dateCeil(max(mydata$date), period) - 3600)
 
     ## find time interval of data and pad any missing times
-    interval <- openair:::find.time.interval(mydata$date)
+    interval <- find.time.interval(mydata$date)
     all.dates <- data.frame(date = seq(start.date, end.date, by = interval))
     mydata <- merge(mydata, all.dates, all = TRUE)
 
@@ -334,8 +333,8 @@ summaryPlot <- function(mydata,
 
                    ## override scaling for more sensible date/time breaks
                    scales = list(y = list(draw = FALSE),
-                   x = list(at = openair:::dateBreaks(mydata$date, date.breaks)$major,
-                   format = openair:::dateBreaks(mydata$date, date.breaks)$format)),
+                   x = list(at = dateBreaks(mydata$date, date.breaks)$major,
+                   format = dateBreaks(mydata$date, date.breaks)$format)),
                    layout = c(1, length(unique(mydata$variable))),
                    strip = FALSE,
                    strip.left = strip.custom(horizontal = FALSE, factor.levels = pol.name),
@@ -382,7 +381,7 @@ summaryPlot <- function(mydata,
                    })
 
     #reset for extra.args
-    xyplot.args<- openair:::listUpdate(xyplot.args, extra.args)
+    xyplot.args<- listUpdate(xyplot.args, extra.args)
 
     #plot
     plt1 <- do.call(xyplot, xyplot.args)
